@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.48 2002/04/30 15:17:54 paolo Exp $ */
+/* $Id: gdict-app.c,v 1.29 2001/12/07 18:19:41 seth Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -36,9 +36,10 @@
 
 #ifdef HAVE_GNOME_PRINT
 #  include <libgnomeprint/gnome-printer-dialog.h>
+#  include <libgnomeprint/gnome-printer-profile.h>
 #endif /* HAVE_GNOME_PRINT */
 
-#define APPNAME "gnome-dictionary"
+#define APPNAME "gdict"
 
 GtkWidget *gdict_app;
 GtkWidget *gdict_appbar;
@@ -48,7 +49,6 @@ GDictDefbox *defbox;
 GDictSpeller *speller;
 GtkWidget *pref_dialog;
 GtkWidget *socket_error_dialog;
-gboolean  gail_loaded = FALSE;
 
 #ifdef HAVE_GNOME_PRINT
 GnomePrinter *gdict_printer = NULL;
@@ -66,12 +66,12 @@ socket_dialog_close_cb (GtkWidget *widget, gpointer data)
 static void
 socket_error_cb (GtkWidget *widget, gchar *message, gpointer data) 
 {
-    socket_error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  		  GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  		  "%s", message, NULL); 
-    gtk_dialog_run (GTK_DIALOG (socket_error_dialog));
-    gtk_widget_destroy (socket_error_dialog);
-    
+    if (!socket_error_dialog) {
+        socket_error_dialog = 
+            gnome_error_dialog_parented (message, GTK_WINDOW (gdict_app));
+        gtk_signal_connect (GTK_OBJECT (socket_error_dialog), "close",
+                            GTK_SIGNAL_FUNC (socket_dialog_close_cb), NULL);
+    }
 }
 
 /* gdict_init_context
@@ -136,6 +136,13 @@ spell_not_found_cb (GtkWidget *widget, gpointer data)
     gnome_appbar_refresh (GNOME_APPBAR (gdict_appbar));
 }
 
+static gint
+spell_close_cb (GtkWidget *widget, gpointer data) 
+{
+    speller = NULL;
+    return FALSE;
+}
+
 void
 gdict_open_speller (void) 
 {
@@ -152,10 +159,12 @@ gdict_open_speller (void)
                             GTK_SIGNAL_FUNC (spell_not_found_cb), NULL);
         gtk_signal_connect (GTK_OBJECT (speller), "socket_error",
                             GTK_SIGNAL_FUNC (socket_error_cb), NULL);
-        gtk_widget_show_all (GTK_WIDGET (speller));
+        gtk_signal_connect (GTK_OBJECT (speller), "close",
+                            GTK_SIGNAL_FUNC (spell_close_cb), NULL);
     }
-    else
-    	gtk_window_present (GTK_WINDOW (speller));
+    
+    if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (speller)))
+    	gtk_widget_show (GTK_WIDGET (speller));
 }
 
 
@@ -414,7 +423,7 @@ find_cb (GtkMenuItem *menuitem, gpointer user_data)
 {
     if (!defbox->def_cmd)
         return;
-    gnome_appbar_pop (GNOME_APPBAR (gdict_appbar));
+
     gnome_appbar_set_prompt (GNOME_APPBAR (gdict_appbar), _("Find:"), TRUE);
 }
 
@@ -427,6 +436,13 @@ find_again_cb (GtkMenuItem *menuitem, gpointer user_data)
         gdict_defbox_find (defbox, find_text, FALSE);
 }
 
+static gint
+pref_dialog_close_cb (GtkWidget *widget, gpointer user_data) 
+{
+    pref_dialog = NULL;
+    return FALSE;
+}
+
 static void
 pref_dialog_apply_cb (GtkWidget *widget, gpointer user_data) 
 {
@@ -440,23 +456,28 @@ gdict_not_online ()
     GtkWidget *w;
     gchar *s;
     
-    s = g_strdup_printf (_("Unable to perform requested operation. \n"
-    		           "Either the server you are using is not available \n"
-    		           "or you are not connected to the Internet."));
-    w = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                     "%s", s, NULL); 
-    gtk_dialog_run (GTK_DIALOG (w));
-    gtk_widget_destroy (w);
+    s = g_strdup_printf (_("Unable to perform requested operation, either because the server\n"
+			   "you are using is down or because you are not connected to the\n"
+			   "Internet. If you are not already connected to the Internet, please\n" 
+    			   "do so and try again."));
+    w = gnome_error_dialog (s);
+    gnome_dialog_run_and_close (GNOME_DIALOG (w));
     g_free (s);
 }
 
 void
 gdict_app_show_preferences (void) 
 {
-	
-    if (!pref_dialog)
+    if (!pref_dialog) {
         pref_dialog = gdict_pref_dialog_new (context);
+        gtk_signal_connect (GTK_OBJECT (pref_dialog), "apply_changes",
+                            GTK_SIGNAL_FUNC (pref_dialog_apply_cb), NULL);
+        gtk_signal_connect (GTK_OBJECT (pref_dialog), "socket_error",
+                            GTK_SIGNAL_FUNC (socket_error_cb), NULL);
+        gtk_signal_connect (GTK_OBJECT (pref_dialog), "close",
+                            GTK_SIGNAL_FUNC (pref_dialog_close_cb),
+			    NULL);
+    }
 
     gtk_widget_show (pref_dialog);
 }
@@ -473,116 +494,11 @@ about_cb (GtkMenuItem *menuitem, gpointer user_data)
     gdict_about();
 }
 
-
-/*
- * add_atk_namedesc
- * @widget    : The Gtk Widget for which @name and @desc are added.
- * @name      : Accessible Name
- * @desc      : Accessible Description
- * Description: This function adds accessible name and description to a
- *              Gtk widget.
- */
-
-void
-add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc)
-{
-    AtkObject *atk_widget;
-
-    g_return_if_fail (GTK_IS_WIDGET(widget));
-
-    atk_widget = gtk_widget_get_accessible(widget);
-    
-    if( name != NULL )
-    atk_object_set_name(atk_widget, name);
-    if( desc !=NULL )
-    atk_object_set_description(atk_widget, desc);
-}
-
-
-/*
- * add_atk_relation
- * @obj1      : The first widget in the relation @rel_type
- * @obj2      : The second widget in the relation @rel_type.
- * @rel_type  : Relation type which relates @obj1 and @obj2
- * Description: This function establishes Atk Relation between two given
- *              objects.
- */
-
-void
-add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType rel_type)
-{
-
-    AtkObject *atk_obj1, *atk_obj2;
-    AtkRelationSet *relation_set;
-    AtkRelation *relation;
-
-    g_return_if_fail (GTK_IS_WIDGET(obj1));
-    g_return_if_fail (GTK_IS_WIDGET(obj2));
-
-    atk_obj1 = gtk_widget_get_accessible(obj1);
-
-    atk_obj2 = gtk_widget_get_accessible(obj2);
-
-    relation_set = atk_object_ref_relation_set (atk_obj1);
-    relation = atk_relation_new(&atk_obj2, 1, rel_type);
-    atk_relation_set_add(relation_set, relation);
-    g_object_unref(G_OBJECT (relation));
-
-}
-
-GtkWidget* 
-gdict_button_new_with_stock_image (const gchar* text, const gchar* stock_id)
-{
-	GtkWidget *button;
-	GtkStockItem item;
-	GtkWidget *label;
-	GtkWidget *image;
-	GtkWidget *hbox;
-	GtkWidget *align;
-
-	button = gtk_button_new ();
-
- 	if (GTK_BIN (button)->child)
-    		gtk_container_remove (GTK_CONTAINER (button),
-				      GTK_BIN (button)->child);
-
-  	if (gtk_stock_lookup (stock_id, &item))
-    	{
-      		label = gtk_label_new_with_mnemonic (text);
-
-		gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-      
-		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-      		hbox = gtk_hbox_new (FALSE, 2);
-
-      		align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-      
-      		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-      		gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-      
-      		gtk_container_add (GTK_CONTAINER (button), align);
-      		gtk_container_add (GTK_CONTAINER (align), hbox);
-      		gtk_widget_show_all (align);
-
-      		return button;
-    	}
-
-      	label = gtk_label_new_with_mnemonic (text);
-      	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-  
-  	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
-
-  	gtk_widget_show (label);
-  	gtk_container_add (GTK_CONTAINER (button), label);
-
-	return button;
-}
-
-static GnomeUIInfo dictionary_menu_uiinfo[] = {
-    GNOMEUIINFO_ITEM_STOCK (N_("_Look Up Word"),
+static GnomeUIInfo file_menu_uiinfo[] = {
+    GNOMEUIINFO_ITEM_STOCK (N_("Lookup"),
 			    N_("Lookup word in dictionary"),
 			    lookup_cb, GNOME_STOCK_MENU_SEARCH),
-    GNOMEUIINFO_ITEM_STOCK (N_("Check _Spelling"), 
+    GNOMEUIINFO_ITEM_STOCK (N_("Spell"), 
 			    N_("Check word spelling"), 
 			    spell_cb, GNOME_STOCK_MENU_SPELLCHECK),
 #ifdef HAVE_GNOME_PRINT
@@ -591,7 +507,7 @@ static GnomeUIInfo dictionary_menu_uiinfo[] = {
     GNOMEUIINFO_MENU_PRINT_SETUP_ITEM (print_setup_cb, NULL),
 #endif /* HAVE_GNOME_PRINT */
     GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_MENU_QUIT_ITEM(exit_cb, NULL),
+    GNOMEUIINFO_MENU_EXIT_ITEM (exit_cb, NULL),
     GNOMEUIINFO_END
 };
 
@@ -613,12 +529,13 @@ static GnomeUIInfo edit_menu_uiinfo[] = {
     GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_MENU_FIND_ITEM (find_cb, NULL),
     GNOMEUIINFO_MENU_FIND_AGAIN_ITEM (find_again_cb, NULL),
-    GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cb, NULL),
     GNOMEUIINFO_END
 };
 
-
+static GnomeUIInfo settings_menu_uiinfo[] = {
+    GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cb, NULL),
+    GNOMEUIINFO_END
+};
 
 static GnomeUIInfo help_menu_uiinfo[] = {
     GNOMEUIINFO_HELP(APPNAME),
@@ -627,14 +544,37 @@ static GnomeUIInfo help_menu_uiinfo[] = {
 };
 
 static GnomeUIInfo menubar_uiinfo[] = {
-    { GNOME_APP_UI_SUBTREE_STOCK, N_("_Dictionary"), NULL, 
-      dictionary_menu_uiinfo, NULL, NULL, (GnomeUIPixmapType) 0, 
-      NULL, 0, (GdkModifierType) 0, NULL },
+    GNOMEUIINFO_MENU_FILE_TREE (file_menu_uiinfo),
     GNOMEUIINFO_MENU_EDIT_TREE (edit_menu_uiinfo),
+    GNOMEUIINFO_MENU_SETTINGS_TREE (settings_menu_uiinfo),
     GNOMEUIINFO_MENU_HELP_TREE (help_menu_uiinfo),
     GNOMEUIINFO_END
 };
 
+static GnomeUIInfo toolbar_uiinfo[] = {
+    GNOMEUIINFO_ITEM_STOCK (N_("Lookup"), 
+			    N_("Lookup word in dictionary"), 
+			    lookup_cb, GNOME_STOCK_PIXMAP_SEARCH),
+    GNOMEUIINFO_ITEM_STOCK (N_("Spell"), 
+			    N_("Check word spelling"), 
+			    spell_cb, GNOME_STOCK_PIXMAP_SPELLCHECK),
+    GNOMEUIINFO_SEPARATOR,
+    GNOMEUIINFO_ITEM_STOCK (N_("Cut"), 
+			    N_("Cut to Clipboard"), 
+			    cut_cb, GNOME_STOCK_PIXMAP_CUT),
+    GNOMEUIINFO_ITEM_STOCK (N_("Copy"), 
+			    N_("Copy to Clipboard"), 
+			    copy_cb, GNOME_STOCK_PIXMAP_COPY),
+    GNOMEUIINFO_ITEM_STOCK (N_("Paste"), 
+			    N_("Paste Clipboard Contents"), 
+			    paste_cb, GNOME_STOCK_PIXMAP_PASTE),
+    GNOMEUIINFO_SEPARATOR,
+    GNOMEUIINFO_ITEM_STOCK (N_("Settings"), 
+			  N_("Server to use, default search strategy, fonts"), 
+			    preferences_cb, GNOME_STOCK_PIXMAP_PREFERENCES),
+    GNOMEUIINFO_END
+};
+
 enum
 {
   TARGET_STRING,
@@ -649,7 +589,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     GtkWidget *vbox;
     GtkWidget *hbox;
     GtkWidget *button;
-    GtkWidget *label, *word_label;
+    GtkWidget *label;
     GtkWidget *scrolled;
     GtkWidget *defbox_vscrollbar;
     GtkTooltips *tooltips;
@@ -663,34 +603,36 @@ GtkWidget *gdict_app_create (gboolean applet) {
   
     tooltips = gtk_tooltips_new ();
   
-    gdict_app = gnome_app_new ("gnome-dictionary", _("Dictionary"));
+    gdict_app = gnome_app_new ("Dictionary", "Dictionary");
     gtk_window_set_default_size (GTK_WINDOW (gdict_app), 450, 330);
     
     dock = GNOME_APP (gdict_app)->dock;
     gtk_widget_show (dock);
     
     if (applet)  /* quick hack */
-        memcpy (&dictionary_menu_uiinfo[EXIT_FILE_MENU_ITEM],
+        memcpy (&file_menu_uiinfo[EXIT_FILE_MENU_ITEM],
 		&applet_close_item, sizeof(GnomeUIInfo));
 
     gnome_app_create_menus (GNOME_APP (gdict_app), menubar_uiinfo);
+    gnome_app_create_toolbar (GNOME_APP (gdict_app), toolbar_uiinfo);
     
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
     gnome_app_set_contents (GNOME_APP (gdict_app), vbox);
     
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_container_set_border_width (GTK_CONTAINER (hbox), GNOME_PAD_SMALL);
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    word_label = gtk_label_new_with_mnemonic (_("_Word: "));
-    gtk_widget_show ( GTK_WIDGET(word_label) );
-    gtk_box_pack_start (GTK_BOX (hbox), word_label, FALSE, FALSE, 0);
+    label = gtk_label_new_with_mnemonic (_("_Lookup"));
+    gtk_widget_show (label);
+    gtk_misc_set_padding (GTK_MISC (label), 2, 1);
     
-    button = gdict_button_new_with_stock_image (_("_Look Up Word"), GTK_STOCK_FIND);
+    button = gtk_button_new ();
+    gtk_container_add (GTK_CONTAINER (button), label);
     gtk_widget_show (button);
-    gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
     gtk_drag_dest_set (button, GTK_DEST_DEFAULT_ALL, drop_targets, 
     		       G_N_ELEMENTS (drop_targets), GDK_ACTION_COPY | GDK_ACTION_MOVE);
     g_signal_connect (G_OBJECT (button), "clicked",
@@ -698,33 +640,20 @@ GtkWidget *gdict_app_create (gboolean applet) {
     g_signal_connect (G_OBJECT (button), "drag_data_received",
     		      G_CALLBACK (lookup_button_drag_cb), defbox);
 
-    gnome_word_entry = gnome_entry_new ("Wordentry");
+    gnome_word_entry = gnome_entry_new ("Word entry");
     gtk_widget_show (gnome_word_entry);
+    /*gtk_box_pack_start (GTK_BOX (vbox), gnome_word_entry, FALSE, FALSE, 0);*/
     gtk_box_pack_start (GTK_BOX (hbox), gnome_word_entry, TRUE, TRUE, 0);
+    GTK_WIDGET_SET_FLAGS (gnome_word_entry, GTK_CAN_FOCUS);
+    gtk_widget_grab_focus (gnome_word_entry);
     gnome_entry_set_max_saved (GNOME_ENTRY (gnome_word_entry), 50);
     word_entry = gnome_entry_gtk_entry(GNOME_ENTRY (gnome_word_entry));
-   
-    gtk_label_set_mnemonic_widget (GTK_LABEL (word_label), word_entry);
-    GTK_WIDGET_SET_FLAGS (word_entry, GTK_CAN_FOCUS);
-    gtk_widget_grab_focus (word_entry);
-
-    if ( GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(gnome_word_entry)))
-    {
-        gail_loaded = TRUE;
-        add_atk_namedesc(GTK_WIDGET(word_label), _("Word"), _("Word"));
-        add_atk_namedesc(gnome_word_entry, _("Word Entry"), _("Enter a Word or select one from the list below"));
-        add_atk_namedesc(word_entry, _("Word Entry"), NULL);
-        add_atk_relation(gnome_word_entry, GTK_WIDGET(word_label), ATK_RELATION_LABELLED_BY);
-        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Look Up for a Word"));
-    }
-
+        
     scrolled = gtk_scrolled_window_new (NULL, NULL);
     gtk_container_set_border_width (GTK_CONTAINER (scrolled), GNOME_PAD_SMALL);    
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                        GTK_POLICY_AUTOMATIC,             
-	       				GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_ETCHED_IN);
-
+                                        GTK_POLICY_AUTOMATIC,
+                                        GTK_POLICY_AUTOMATIC);
     gtk_widget_show (scrolled);
   
     defbox = GDICT_DEFBOX (gdict_defbox_new ());
@@ -747,10 +676,10 @@ GtkWidget *gdict_app_create (gboolean applet) {
 
     gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
 
-    gdict_appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_ALWAYS);
+    gdict_appbar = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_ALWAYS);
     gtk_widget_show (gdict_appbar);
     gnome_app_set_statusbar (GNOME_APP (gdict_app), gdict_appbar);
-
+   
     if (!applet)
       gtk_signal_connect (GTK_OBJECT (gdict_app), "delete_event",
                           GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
