@@ -49,7 +49,7 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
 	  NULL
   };
   /* Translator credits */
-  gchar *translator_credits = _("translator_credits");
+  gchar *translator_credits = _("");
 
   if (about_window != NULL) {
 	  gtk_widget_show_now (about_window);
@@ -60,7 +60,7 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
   {
 	  gchar *logo_fn = NULL;
 
-	  logo_fn = gnome_pixmap_file("gnome-system-log/logview.xpm");
+	  logo_fn = gnome_pixmap_file("logview/logview.xpm");
 	  if (logo_fn != NULL)
 	  {
 		  logo = gdk_pixbuf_new_from_file(logo_fn, NULL);
@@ -69,12 +69,12 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
   }
 
   /* go get logview.xpm in $(prefix)/share/pixmaps/logview */
-  about_window = gnome_about_new (_("GNOME System Log"), VERSION,
+  about_window = gnome_about_new (_("Logview"), VERSION,
            			  N_("Copyright (C) 1998"),
 				  _(comments),
 				  author,
 				  (const char **)documenters,
-				  strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				  (const char *)translator_credits,
 				  logo);
   if (app != NULL)
 	  gtk_window_set_transient_for (GTK_WINDOW (about_window),
