@@ -24,7 +24,6 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <gconf/gconf-client.h>
 #include <unistd.h>
 #include <time.h>
 #include <sys/stat.h>
@@ -43,7 +42,6 @@ gboolean log_repaint (GtkWidget * canvas, GdkRectangle * area);
 gboolean PointerMoved (GtkWidget * canvas, GdkEventMotion * event);
 gboolean HandleLogKeyboard (GtkWidget * win, GdkEventKey * event_key);
 gboolean handle_log_mouse_button (GtkWidget * win, GdkEventButton *event);
-gboolean handle_log_mouse_scroll (GtkWidget * win, GdkEventScroll *event);
 void ExitProg (GtkWidget * widget, gpointer user_data);
 void LoadLogMenu (GtkWidget * widget, gpointer user_data);
 void CloseLogMenu (GtkWidget * widget, gpointer user_data);
@@ -75,7 +73,6 @@ void print_db (GList *gb);
 Log *OpenLogFile (char *);
 GtkWidget *new_pixmap_from_data (char  **, GdkWindow *, GdkColor *);
 GtkWidget *create_menu (char *item[], int n);
-void SaveUserPrefs(UserPrefsStruct *prefs);
 
 /*
  *    ,-------.
@@ -116,11 +113,9 @@ GnomeUIInfo view_menu[] = {
         {GNOME_APP_UI_ITEM, N_("Zoom"), 
 	 N_("Show line info"), create_zoom_view, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 'Z', GDK_CONTROL_MASK, NULL},
-       /* {GNOME_APP_UI_ITEM, N_("Preferences..."), 
+        {GNOME_APP_UI_ITEM, N_("Preferences..."), 
 	 N_("Show user preferences"), UserPrefsDialog, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 'P', GDK_CONTROL_MASK, NULL},*/
-	/* As of now  user preference dialog does nothing except 
-        the hostname width adjustment in displaying */
+         GNOME_APP_PIXMAP_NONE, NULL, 'P', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
@@ -137,7 +132,6 @@ GnomeUIInfo filter_menu[] = {
 #endif
 
 GnomeUIInfo help_menu[] = {
-	GNOMEUIINFO_HELP("gnome-system-log"),
         {GNOME_APP_UI_ITEM, N_("About..."), 
 	 N_("Info about logview"), AboutShowWindow,
          NULL, NULL,
@@ -164,8 +158,6 @@ GnomeUIInfo main_menu[] = {
 
 GtkWidget *app = NULL;
 GtkWidget *main_win_scrollbar = NULL;
-static GtkWidget *viewport;
-GtkWidget *main_win_hor_scrollbar = NULL; 
 GtkLabel *filename_label = NULL, *date_label = NULL;
 
 GList *regexp_db = NULL, *descript_db = NULL, *actions_db = NULL;
@@ -174,26 +166,11 @@ UserPrefsStruct user_prefs_struct = {0};
 ConfigData *cfg = NULL;
 GtkWidget *open_file_dialog = NULL;
 
-GConfClient *client;
-poptContext poptCon;
-gint next_opt;
-
-struct poptOption options[] = { {
-	"file",
-	'f',
-	POPT_ARG_STRING,
-	NULL,
-	1,
-	NULL,
-	NULL,
-} };
-
 extern GdkGC *gc;
 extern Log *curlog, *loglist[];
 extern int numlogs, curlognum;
 extern int loginfovisible, calendarvisible;
 extern int cursor_visible;
-extern PangoLayout *log_layout;
 
 /* ----------------------------------------------------------------------
    NAME:          destroy
@@ -206,70 +183,6 @@ destroy (void)
    CloseApp ();
 }
 
-static gint
-save_session (GnomeClient *gclient, gint phase,
-              GnomeRestartStyle save_style, gint shutdown,
-              GnomeInteractStyle interact_style, gint fast,
-              gpointer client_data)
-{
-   gchar **argv;
-   gint i;
-
-   argv = g_malloc0 (sizeof (gchar *) * (numlogs+1));
-   argv[0] = (gchar *) client_data;
-   for ( i = 1; i <= numlogs; i++) 
-       argv[i] = g_strconcat ("--file=", loglist[i-1]->name, NULL);
-   
-   gnome_client_set_clone_command (gclient, numlogs+1, argv);
-   gnome_client_set_restart_command (gclient, numlogs+1, argv);
-
-   g_free (argv);
-
-   return TRUE;
-}
-
-static gboolean
-restore_session (void)
-{
-   Log *tl;
-   gint i, logcnt = 0;
-
-   /* closing the log file opened by default */
-   CloseLog (loglist[0]);
-   curlog = NULL;
-   loglist[0] = NULL;
-   curlognum = 0;
-   log_repaint (NULL, NULL);
-   if (loginfovisible)
-       RepaintLogInfo (NULL, NULL);
-   set_scrollbar_size (1);
-   numlogs = 0;
-
-   next_opt = poptGetNextOpt (poptCon);
-
-   do {
-      if ( next_opt == 1) {
-         gchar *f = (gchar *) poptGetOptArg (poptCon);
-         if (f != NULL) {
-            if ((tl = OpenLogFile (f)) != NULL) {
-               curlog = tl;
-               loglist[numlogs] = tl;
-               numlogs++;
-               curlognum = numlogs - 1;
-            }
-         }
-         if (f)
-            g_free (f);
-      }
-   } while ((next_opt = poptGetNextOpt (poptCon)) != -1);
-}
-
-static gint
-die (GnomeClient *gclient, gpointer client_data)
-{
-    gtk_main_quit ();
-}
-
 /* ----------------------------------------------------------------------
    NAME:          main
    DESCRIPTION:   Program entry point.
@@ -278,8 +191,6 @@ die (GnomeClient *gclient, gpointer client_data)
 int
 main (int argc, char *argv[])
 {
-  GnomeClient *gclient;
-
   bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
   textdomain(GETTEXT_PACKAGE);
@@ -287,21 +198,10 @@ main (int argc, char *argv[])
   QueueErrMessages (TRUE);
 
   /*  Initialize gnome & gtk */
-  gnome_program_init ("gnome-system-log",VERSION, LIBGNOMEUI_MODULE, argc, argv,
-  		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+  gnome_init ("logview", VERSION, argc, argv);
 
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-log.png");
   
-  poptCon = poptGetContext ("gnome-system-log", argc, (const gchar **) argv, 
-                            options, 0);  
-  gclient = gnome_master_client ();
-  g_signal_connect (gclient, "save_yourself",
-                    G_CALLBACK (save_session), (gpointer)argv[0]);
-  g_signal_connect (gclient, "die", G_CALLBACK (die), NULL);
-
-  gconf_init (argc, argv, NULL);
-  client = gconf_client_get_default ();
-  
   /*  Load graphics config */
   cfg = CreateConfig();
   
@@ -313,14 +213,8 @@ main (int argc, char *argv[])
   QueueErrMessages (FALSE);
   ShowQueuedErrMessages ();
    
-  if (gnome_client_get_flags (gclient) & GNOME_CLIENT_RESTORED) {
-     restore_session ();
-  }
-
   /*  Loop application */
   gtk_main ();
-  
-  SaveUserPrefs(user_prefs);
 
   return 0;
 }
@@ -359,7 +253,7 @@ void
 CreateMainWin ()
 {
    GtkWidget *canvas;
-   GtkWidget *w, *vbox, *table, *hbox, *hbox_date;
+   GtkWidget *w, *box, *table, *hbox2;
    GtkWidget *padding;
    GtkLabel *label;
    GtkObject *adj;
@@ -383,38 +277,40 @@ CreateMainWin ()
    /* Create menus */
    gnome_app_create_menus (GNOME_APP (app), main_menu);
 
-   vbox = gtk_vbox_new (FALSE, 0);
-   gnome_app_set_contents (GNOME_APP (app), vbox);
+   box = gtk_vbox_new (FALSE, 0);
+   gnome_app_set_contents (GNOME_APP (app), box);
 
    /* Deactivate unfinished items */
    gtk_widget_set_state (file_menu[1].widget, GTK_STATE_INSENSITIVE);
    if (numlogs < 2)
      gtk_widget_set_state (file_menu[3].widget, GTK_STATE_INSENSITIVE);
+#if 0
+   gtk_widget_set_state (filter_menu[0].widget, GTK_STATE_INSENSITIVE);
+   gtk_widget_set_state (filter_menu[1].widget, GTK_STATE_INSENSITIVE);
+#endif
 
    /* Create main canvas and scroll bars */
    table = gtk_table_new (2, 2, FALSE);
    gtk_widget_show (table);
 
-   viewport = gtk_viewport_new (NULL, NULL);
-   gtk_widget_set_size_request (viewport, LOG_CANVAS_W, 0); 
-   gtk_widget_show (viewport);
+   w = gtk_viewport_new (NULL, NULL);
+   gtk_widget_set_usize (w, LOG_CANVAS_W, 0); 
+   gtk_widget_show (w);
                
    canvas = gtk_drawing_area_new ();
+   /*gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, LOG_CANVAS_H); */
    gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W,
 			  LOG_CANVAS_H); 
-   gtk_container_add (GTK_CONTAINER (viewport), canvas);
-   gtk_table_attach (GTK_TABLE (table), viewport, 0, 1, 0, 1,
+   /*gtk_widget_set_usize ( GTK_WIDGET (canvas), LOG_CANVAS_W, LOG_CANVAS_H);*/
+   gtk_container_add (GTK_CONTAINER (w), canvas);
+   gtk_table_attach (GTK_TABLE (table), w, 0, 1, 0, 1,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 
-   if (curlog != NULL)
-	   adj = (GtkObject *)gtk_viewport_get_hadjustment (GTK_VIEWPORT (viewport));
-   else
-	   adj = gtk_adjustment_new (100.0, 0.0, 101.0, 1, 10, 101.0);
-   
-   main_win_hor_scrollbar = gtk_hscrollbar_new (GTK_ADJUSTMENT (adj));
-   gtk_widget_show(main_win_hor_scrollbar);
-   gtk_table_attach (GTK_TABLE (table), main_win_hor_scrollbar, 0, 1, 1, 2,
+   adj = (GtkObject *)gtk_viewport_get_hadjustment (GTK_VIEWPORT (w));
+   w = gtk_hscrollbar_new (GTK_ADJUSTMENT (adj));
+   gtk_widget_show (w);
+   gtk_table_attach (GTK_TABLE (table), w, 0, 1, 1, 2,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		     (GtkAttachOptions) (0), 0, 0);
 
@@ -434,75 +330,73 @@ CreateMainWin ()
    gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
 		       (GtkSignalFunc) MainWinScrolled,
 		       (gpointer) main_win_scrollbar);       
+   gtk_signal_connect (GTK_OBJECT (main_win_scrollbar), "button_release_event", 
+ 		       (GtkSignalFunc) ScrollWin, 
+ 		       (gpointer) main_win_scrollbar);        
    gtk_widget_show (main_win_scrollbar);  
 
 
-   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
+   gtk_box_pack_start (GTK_BOX (box), table, TRUE, TRUE, 0);
    
    /*  Install event handlers */
    gtk_signal_connect (GTK_OBJECT (canvas), "expose_event",
 		       GTK_SIGNAL_FUNC (log_repaint), NULL);
+   gtk_signal_connect (GTK_OBJECT (canvas), "motion_notify_event",
+		       GTK_SIGNAL_FUNC (PointerMoved), NULL);
    gtk_signal_connect (GTK_OBJECT (app), "key_press_event",
 		       GTK_SIGNAL_FUNC (HandleLogKeyboard), NULL);
-   gtk_signal_connect (GTK_OBJECT (canvas), "button_press_event",
+   gtk_signal_connect (GTK_OBJECT (app), "button_press_event",
 		       GTK_SIGNAL_FUNC (handle_log_mouse_button), NULL);
-   g_signal_connect (G_OBJECT (canvas), "scroll_event", 
-   		     G_CALLBACK (handle_log_mouse_scroll), NULL);
    gtk_signal_connect (GTK_OBJECT (canvas), "size_allocate",
 		       GTK_SIGNAL_FUNC (CanvasResized), NULL);
    gtk_widget_set_events (canvas, GDK_EXPOSURE_MASK |
 			  GDK_BUTTON_PRESS_MASK |
-			  GDK_POINTER_MOTION_MASK |
-			  GDK_SCROLL_MASK
-			  );
+			  GDK_POINTER_MOTION_MASK );
 
    gtk_widget_set_events (app, GDK_KEY_PRESS_MASK);
 
 
+   /*gtk_widget_set_style (canvas, cfg->black_bg_style); */
    gtk_widget_set_style (canvas, cfg->white_bg_style);
    gtk_widget_show (canvas);
 
 
    /* Create status area at bottom */
-   hbox = gtk_hbox_new (FALSE, 2);
-   gtk_container_set_border_width ( GTK_CONTAINER (hbox), 3);
+   hbox2 = gtk_hbox_new (FALSE, 2);
+   gtk_container_set_border_width ( GTK_CONTAINER (hbox2), 3);
 
    label = (GtkLabel *)gtk_label_new (_("Filename: "));
    gtk_label_set_justify (label, GTK_JUSTIFY_LEFT);
-   gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, 0);
+   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (label), FALSE, FALSE, 0);
    gtk_widget_show (GTK_WIDGET (label));  
 
    filename_label = (GtkLabel *)gtk_label_new ("");
    gtk_widget_show ( GTK_WIDGET (filename_label));  
    gtk_label_set_justify (label, GTK_JUSTIFY_LEFT);
-   gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (filename_label), 
+   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (filename_label), 
 		       FALSE, FALSE, 0);
    
    /* Add padding to right justify */
    padding = gtk_label_new (" ");
    gtk_widget_show (padding);
-   gtk_box_pack_start (GTK_BOX (hbox), padding, TRUE, TRUE, 0);
+   gtk_box_pack_start (GTK_BOX (hbox2), padding, TRUE, TRUE, 0);
 
-   hbox_date = gtk_hbox_new (FALSE, 2);
-   gtk_container_set_border_width ( GTK_CONTAINER (hbox_date), 3);
-
-   label = (GtkLabel *)gtk_label_new (_("Last Modified: "));
+   label = (GtkLabel *)gtk_label_new (_("Date: "));
    gtk_label_set_justify (label, GTK_JUSTIFY_RIGHT);
-   /* gtk_widget_set_size_request (GTK_WIDGET(label), 240, -1); */
-   gtk_box_pack_start (GTK_BOX (hbox_date), GTK_WIDGET (label), FALSE, FALSE, 0);
+   gtk_widget_set_usize (GTK_WIDGET(label), 40, -1);
+   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (label), FALSE, FALSE, 0);
    gtk_widget_show (GTK_WIDGET (label));  
 
    date_label = (GtkLabel *)gtk_label_new ("");
    gtk_widget_show (GTK_WIDGET (date_label));  
-   /* gtk_widget_set_size_request (GTK_WIDGET (label), 60, -1); */
-   gtk_box_pack_start (GTK_BOX (hbox_date), GTK_WIDGET (date_label), TRUE, TRUE, 0);
+   gtk_widget_set_usize (GTK_WIDGET (label), 60, -1);
+   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (date_label), FALSE, FALSE, 0);
 
-   gtk_widget_show (hbox_date);
-   gtk_box_pack_start (GTK_BOX (hbox), hbox_date, FALSE, FALSE, 0);
-   gtk_widget_show (hbox);
-   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+   gtk_widget_show (hbox2);
 
-   gtk_widget_show (vbox);
+   gtk_box_pack_start (GTK_BOX (box), hbox2, FALSE, FALSE, 0);
+
+   gtk_widget_show (box);
    gtk_widget_show (app);
 
 }
@@ -639,6 +533,7 @@ void set_scrollbar_size (int num_lines)
 {
   GtkObject *adj;
 
+  /*adj = gtk_adjustment_new ( curlog->ln, 0.0, num_lines+LINES_P_PAGE, 1.0, 10.0, (float) LINES_P_PAGE);*/
   adj = gtk_adjustment_new (-1, 0.0, num_lines,
 			    1.0, 10.0, (float) LINES_P_PAGE);
   gtk_range_set_adjustment (GTK_RANGE (main_win_scrollbar),
@@ -646,22 +541,10 @@ void set_scrollbar_size (int num_lines)
   gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
 		      (GtkSignalFunc) MainWinScrolled,
 		      (gpointer) main_win_scrollbar);       
-  if (curlog != NULL )
-  {
-  	gtk_adjustment_set_value (GTK_ADJUSTMENT(adj), curlog->ln); 
-	adj = (GtkObject*)gtk_viewport_get_hadjustment (GTK_VIEWPORT (viewport));
-  	gtk_adjustment_set_value (GTK_ADJUSTMENT(adj),0); 
-  }
-  else
-	adj = gtk_adjustment_new (100.0, 0.0, 101.0, 1, 10, 101.0);
-
-  gtk_range_set_adjustment (GTK_RANGE (main_win_hor_scrollbar),GTK_ADJUSTMENT (adj));
-
+  gtk_adjustment_set_value (GTK_ADJUSTMENT(adj), curlog->ln);
   gtk_widget_realize (main_win_scrollbar);
-  gtk_widget_realize (main_win_hor_scrollbar);
 
   gtk_widget_queue_resize (main_win_scrollbar);
-  gtk_widget_queue_resize (main_win_hor_scrollbar);
 }
 
 /* ----------------------------------------------------------------------
@@ -687,11 +570,6 @@ CloseLogMenu (GtkWidget * widget, gpointer user_data)
       log_repaint (NULL, NULL);
       if (loginfovisible)
 	 RepaintLogInfo (NULL, NULL);
-      set_scrollbar_size (1);
-      gtk_widget_set_sensitive (file_menu[2].widget, FALSE); 
-      gtk_widget_set_sensitive (file_menu[4].widget, FALSE); 
-      for ( i = 0; i < 4; i++) 
-         gtk_widget_set_sensitive (view_menu[i].widget, FALSE); 
       return;
    }
    for (i = curlognum; i < numlogs; i++)
@@ -764,16 +642,8 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
 	 /* Set main scrollbar */
 	 set_scrollbar_size (curlog->lstats.numlines);
 
-	 if (numlogs)
-	 {
-	   int i;
-	   if (numlogs >= 2)
-	     gtk_widget_set_sensitive (file_menu[3].widget, TRUE);
-	   gtk_widget_set_sensitive (file_menu[2].widget, TRUE);
-	   gtk_widget_set_sensitive (file_menu[4].widget, TRUE);
-	   for ( i = 0; i < 4; i++) 
-	     gtk_widget_set_sensitive (view_menu[i].widget, TRUE);
-	 } 
+	 if (numlogs >= 2)
+	   gtk_widget_set_sensitive (file_menu[3].widget, TRUE);
       }
    }
    g_free (f);
@@ -792,10 +662,7 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
 
    /*  Cannot open more than MAX_NUM_LOGS */
    if (numlogs == MAX_NUM_LOGS)
-     { 
-       ShowErrMessage (_("Too many open logs. Close one and try again")); 
-       return;
-     }
+      return;
    
    /*  Cannot have more than one fileselect window */
    /*  at one time. */
@@ -814,8 +681,7 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
    gtk_window_set_modal (GTK_WINDOW (filesel), TRUE);
 
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), 
-   				    user_prefs->logfile);
-
+   				    PATH_MESSAGES);
    gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
    gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
 		       "clicked", (GtkSignalFunc) FileSelectOk,
@@ -861,12 +727,7 @@ CloseApp (void)
    for (i = 0; i < numlogs; i++)
       CloseLog (loglist[i]);
 
-   numlogs = 0;
-
-   if (G_IS_OBJECT (log_layout))
-      g_object_unref (G_OBJECT (log_layout));
-
-   gtk_main_quit ();   
+   gtk_exit (0);
 }
 
 /* ----------------------------------------------------------------------
@@ -885,7 +746,7 @@ open_databases (void)
 	found = FALSE;
 	if (cfg->regexp_db_path != NULL) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/gnome-system-log-regexp.db", cfg->regexp_db_path);
+			    "%s/logview-regexp.db", cfg->regexp_db_path);
 		DB (fprintf (stderr, "Looking for database in [%s]\n", cfg->regexp_db_path));
 		if (access (full_name, R_OK) == 0)  {
 			found = TRUE;
@@ -895,7 +756,7 @@ open_databases (void)
 
 	if ( ! found) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/share/gnome-system-log/gnome-system-log-regexp.db", LOGVIEWINSTALLPREFIX);
+			    "%s/share/logview/logview-regexp.db", LOGVIEWINSTALLPREFIX);
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
 			g_free (cfg->regexp_db_path);
@@ -908,7 +769,7 @@ open_databases (void)
 	found = FALSE;
 	if (cfg->descript_db_path != NULL) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/gnome-system-log-descript.db", cfg->descript_db_path);
+			    "%s/logview-descript.db", cfg->descript_db_path);
 		DB (fprintf (stderr, "Looking for database in [%s]\n", cfg->descript_db_path));
 		if (access (full_name, R_OK) == 0) {
 			read_descript_db (full_name, &descript_db);
@@ -918,7 +779,7 @@ open_databases (void)
 
 	if ( ! found) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/share/gnome-system-log/gnome-system-log-descript.db", LOGVIEWINSTALLPREFIX);
+			    "%s/share/logview/logview-descript.db", LOGVIEWINSTALLPREFIX);
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
 			g_free (cfg->descript_db_path);
@@ -931,7 +792,7 @@ open_databases (void)
 	/* Find action DB ------------------------------------------------  */
 	found = FALSE;
 	g_snprintf (full_name, sizeof (full_name),
-		    "%s/.gnome/gnome-system-log-actions.db", g_get_home_dir ());
+		    "%s/.gnome/logview-actions.db", g_get_home_dir ());
 	DB (fprintf (stderr, "Looking for database in [%s/.gnome]\n",
 		     g_get_home_dir ()));
 	if (access (full_name, R_OK) == 0) {
@@ -941,7 +802,7 @@ open_databases (void)
 
 	if ( ! found && cfg->action_db_path != NULL) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/gnome-system-log-actions.db", cfg->action_db_path);
+			    "%s/logview-actions.db", cfg->action_db_path);
 		DB (fprintf (stderr, "Looking for database in [%s]\n", cfg->action_db_path));
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
@@ -952,7 +813,7 @@ open_databases (void)
 
 	if ( ! found) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/share/gnome-system-log/gnome-system-log-actions.db", LOGVIEWINSTALLPREFIX);
+			    "%s/share/logview/logview-actions.db", LOGVIEWINSTALLPREFIX);
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
 			g_free (cfg->action_db_path);
@@ -982,41 +843,8 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 {
 	/* Make defaults configurable later */
 	/* Will have to save prefs. eventually too*/
-	gchar *logfile = NULL;
-	struct stat filestat;
-	
-	/* FIXME: load saved values. Should install gconf schemas file for
-	** defaults 
-	*/
+
 	prefs->process_column_width = 12;
 	prefs->hostname_column_width = 15;
 	prefs->message_column_width = 24;
-	
-	logfile = gconf_client_get_string (client, "/apps/logview/logfile", NULL);
-	if (logfile != NULL) {
-		prefs->logfile = g_strdup (logfile);
-		g_free (logfile);
-	}
-	else {
-		/* First time running logview. Try to find the logfile */
-		if (lstat("/var/adm/messages", &filestat) == 0) 
-			prefs->logfile = g_strdup ("/var/adm/messages");
-		else if (lstat("/var/log/messages", &filestat) == 0) 
-			prefs->logfile = g_strdup ("/var/log/messages");
-		else
-			prefs->logfile = NULL;
-	}
-	
-}
-
-void SaveUserPrefs(UserPrefsStruct *prefs)
-{
-    gconf_client_set_string (client, "/apps/logview/logfile", prefs->logfile, NULL);
-    gconf_client_set_int (client, "/apps/logview/process_column_width",
-    			  prefs->process_column_width, NULL);
-    gconf_client_set_int (client, "/apps/logview/hostname_column_width",
-    			  prefs->hostname_column_width, NULL);
-    gconf_client_set_int (client, "/apps/logview/message_column_width",
-    			  prefs->message_column_width, NULL);
-
 }
